import datamaestro

class Repository(datamaestro.Repository):
    AUTHOR = """Benjamin Piwowarski <benjamin@piwowarski.fr>"""
    DESCRIPTION = """Machine learning datamaestro repository"""
    NAMESPACE = """ml"""


from datamaestro.data import Generic
from datamaestro.data.csv import Matrix
from datamaestro.definitions import Dataset
from datamaestro.download.single import FileDownloader

@FileDownloader("data", url="https://raw.githubusercontent.com/scikit-learn/scikit-learn/master/sklearn/datasets/data/boston_house_prices.csv")
@Dataset(Generic)
def boston(data):
  """Boston Housing dataset
  
  This dataset contains information collected by the U.S Census Service
  concerning housing in the area of Boston Mass. It was obtained from the
  StatLib archive (http://lib.stat.cmu.edu/datasets/boston), and has been used
  extensively throughout the literature to benchmark algorithms. However, these
  comparisons were primarily done outside of Delve and are thus somewhat
  suspect. The dataset is small in size with only 506 cases. The data was
  originally published by Harrison, D. and Rubinfeld, D.L. `Hedonic prices and
  the demand for clean air', J. Environ. Economics & Management, vol.5, 81-102,
  1978. """
  return {
    "data": Matrix(path=data, names_row=0, ignore=1, target="MEDV")
  }
  


import sys
try:
    from setuptools import setup, find_namespace_packages
except ImportError:
    print("Please upgrade pip: find_namespace_packages not found")
    sys.exit(1)

# Date-based versioning
VERSION='2019.12.04'

setup(
    name='datamaestro_ml',
    version=VERSION,
    description='Machine Learning related datasets',
    author='Benjamin Piwowarski',
    author_email='benjamin@piwowarski.fr',
    url='https://github.com/bpiwowar/datamaestro_ml',
    license='MIT',
    python_requires='>=3.5',
    packages=find_namespace_packages(include="datamaestro_ml.*"),
    package_data={
        '': [ '*.yaml' ]
    },
    install_requires=[
        'datamaestro>=0.5.1'
    ],
    classifiers=[
        'Intended Audience :: Developers',
        'Intended Audience :: Information Technology',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7'
    ],
    entry_points={
        'datamaestro.repositories': [
            'ml = datamaestro_ml:Repository'
        ]
    },

    test_suite='datamaestro_ml.test'
)
